@@ -282,7 +282,6 @@ def json_date(x, fmt="%Y-%m-%d %H:%M:%S", nan_display="", **kwargs):
 def json_timestamp(x, nan_display="", **kwargs):
     """
     Convert value to timestamp (milliseconds) to be used within JSON output
-
     :param x: value to be converted to milliseconds
     :param nan_display: if `x` is :attr:`numpy:numpy.nan` then return this value
     :return: millisecond value
@@ -497,9 +496,9 @@ def coord_type(s):
     if classify_type(find_dtype(s)) != "F":
         return None
     if "lat" in s.name.lower():
-        return None if (~s.dropna().between(-90, 90)).sum() else "lat"
+        return None if (~s.dropna().between(-90, 90, inclusive=True)).sum() else "lat"
     if "lon" in s.name.lower():
-        return None if (~s.dropna().between(-180, 180)).sum() else "lon"
+        return None if (~s.dropna().between(-180, 180, inclusive=True)).sum() else "lon"
     return None
 
 
@@ -734,3 +733,12 @@ def apply(df, func, *args, **kwargs):
         return df.swifter.progress_bar(False).apply(func, *args, **kwargs)
     except ImportError:
         return df.apply(func, *args, **kwargs)
+
+
+def optimize_df(df):
+    for col in df.select_dtypes(include=["object"]):
+        num_unique_values = len(df[col].unique())
+        num_total_values = len(df[col])
+        if num_unique_values / num_total_values < 0.5:
+            df[col] = df[col].astype("category")
+    return df
